Index: src/uk/me/parabola/mkgmap/reader/osm/Element.java
===================================================================
--- src/uk/me/parabola/mkgmap/reader/osm/Element.java	(revision 3796)
+++ src/uk/me/parabola/mkgmap/reader/osm/Element.java	(working copy)
@@ -223,17 +223,7 @@
 		if (tags == null)
 			return "[]";
 
-		StringBuilder sb = new StringBuilder();
-		sb.append('[');
-		for (String nameval : tags) {
-			sb.append(nameval);
-			sb.append(',');
-		}
-		if (sb.length() > 1) {
-			sb.setLength(sb.length()-1);
-		}
-		sb.append(']');
-		return sb.toString();
+		return tags.toString();
 	}
 
 	/**
Index: src/uk/me/parabola/mkgmap/reader/osm/Tags.java
===================================================================
--- src/uk/me/parabola/mkgmap/reader/osm/Tags.java	(revision 3796)
+++ src/uk/me/parabola/mkgmap/reader/osm/Tags.java	(working copy)
@@ -18,7 +18,7 @@
 import java.util.HashMap;
 import java.util.Iterator;
 import java.util.Map;
-import java.util.Map.Entry;
+import java.util.TreeSet;
 
 /**
  * Store the tags that belong to an Element.
@@ -35,7 +35,7 @@
  *
  * @author Steve Ratcliffe
  */
-public class Tags implements Iterable<String> {
+public class Tags {
 	private static final int INIT_SIZE = 8;
 	private static final TagDict tagDict = TagDict.getInstance();  
 
@@ -177,63 +177,6 @@
 		return -1;
 	}
 
-	/**
-	 * Iterates over the tags in a special way that is used to look up in
-	 * the rules.
-	 *
-	 * If you have the tags a=b, c=d then you will get the following strings
-	 * returned: "a=b", "a=*", "c=d", "c=*".
-	 *
-	 * If you add a tag during the iteration, then it is guaranteed to
-	 * appear later in the iteration.
-	 */
-	public Iterator<String> iterator() {
-		return new Iterator<String>() {
-			private int pos;
-
-			public boolean hasNext() {
-				// After every normal entry there is a wild card entry.
-				//if (doWild)
-				//	return true;
-
-				// Normal entries in the map
-				for (int i = pos; i < capacity; i++) {
-					if (values[i] != null) {
-						pos = i;
-						return true;
-					}
-				}
-
-				return false;
-			}
-
-			/**
-			 * Get the next tag as a single string.  Also returns wild card
-			 * entries.
-			 */
-			public String next() {
-				/*if (doWild) {
-					doWild = false;
-					return wild + "=*";
-				} else*/ if (pos < capacity) {
-					for (int i = pos; i < capacity; i++) {
-						if (values[i] != null) {
-							pos = i+1;
-							return (tagDict.get(keys[i]) + "=" + values[i]);
-						}
-					}
-					pos = capacity;
-				}
-
-				return null;
-			}
-
-			public void remove() {
-				throw new UnsupportedOperationException();
-			}
-		};
-	}
-
 	public Iterator<Map.Entry<String, String>> entryIterator() {
 		return new Iterator<Map.Entry<String, String>>() {
 			private int pos;
@@ -307,51 +250,15 @@
 		return map;
 	}
 	
-	public void removeAll() {
-		Arrays.fill(keys, TagDict.INVALID_TAG_VALUE);
-		Arrays.fill(values, null);
-		keySize = 0;
-		size = 0;
-	}
-	
+
 	public String toString() {
-		StringBuilder s =new StringBuilder();
-		s.append("[");
-		Iterator<Entry<String,String>> tagIter = entryIterator();
-		while (tagIter.hasNext()) {
-			Entry<String,String> tag = tagIter.next();
-			if (s.length() > 1) {
-				s.append("; ");
+		// sort the tags by key to make the result predictable and easier to read
+		TreeSet<String> sorted = new TreeSet<>();
+		for (int i = 0; i < capacity; i++) {
+			if (values[i] != null) {
+				sorted.add(tagDict.get(keys[i]) + "=" + values[i]);
 			}
-			s.append(tag.getKey());
-			s.append("=");
-			s.append(tag.getValue());
 		}
-		s.append("]");
-		return s.toString();
+		return sorted.toString();
 	}
-	
-	/**
-	 * Each tag has a position in the TagDict. This routine fills an array
-	 * so that the caller can use direct access. 
-	 * The caller has to make sure that the array is large enough to hold
-	 * the values he is looking for.  
-	 * @param tagVals
-	 * @return
-	 */
-	public int expand(short[] keyArray, String[] tagVals){
-		if (tagVals == null)
-			return 0;
-		int maxKey = tagVals.length - 1;
-		int cntTags = 0;
-		for (int i = 0; i< capacity; i++){
-			short tagKey = keys[i];
-			if (tagKey != TagDict.INVALID_TAG_VALUE && values[i] != null && tagKey <= maxKey){
-				tagVals[tagKey] = values[i];
-				keyArray[cntTags++] = tagKey;
-			}
-
-		}
-		return cntTags;
-	}
 }
Index: test/uk/me/parabola/mkgmap/reader/osm/TagsTest.java
===================================================================
--- test/uk/me/parabola/mkgmap/reader/osm/TagsTest.java	(revision 3796)
+++ test/uk/me/parabola/mkgmap/reader/osm/TagsTest.java	(working copy)
@@ -17,8 +17,6 @@
 package uk.me.parabola.mkgmap.reader.osm;
 
 import java.util.Arrays;
-import java.util.Iterator;
-
 import static org.junit.Assert.*;
 import org.junit.Test;
 
@@ -107,19 +105,4 @@
 		return tags;
 	}
 
-	/**
-	 * Create an iterator over the tags.  This must be initialised to the
-	 * values in SMALL_SET.
-	 * @param tags The tags containing values from SMALL_SET.
-	 * @return An iterator that has iterated over all the tags in set.
-	 */
-	private Iterator<String> iterateOverTags(Tags tags) {
-		Iterator<String> it = tags.iterator();
-		int n = SMALL_SET.length * 2;
-		for (int i = 0; i < n; i++) {
-			assertTrue(it.hasNext());
-			assertNotNull("result should be non null", it.next());
-		}
-		return it;
-	}
 }
